<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"  >

<!-- WARNING : Use to load language pack DO NOT REMOVE -->
<xsl:param name="languagePack" select="'default'"/>

<!-- WARNING : Use to filter evnt DO NOT REMOVE -->
<xsl:param name="dataFilter" select="'none'"/>





<!-- Create an html anchor for Runs -->
<xsl:template match="@verdict" mode="run">
	<a href="#{../@name}" class="{.}"><xsl:value-of select="../@verdictlabel"/></a>
</xsl:template>

<!-- Create an html anchor for Tests -->
<xsl:template match="@verdict" mode="all">
	<a href="#{../@linkid}" class="{.}"><xsl:value-of select="../@verdictlabel"/></a>
</xsl:template>

<!-- Colored verdict in test log only -->
<xsl:template match="@verdict" mode="nolink">
	<span class="{.}"><xsl:value-of select="../@verdictlabel"/></span>
</xsl:template>

<!-- Colored verdict in test title -->
<xsl:template match="@verdict" mode="nolinktitle">
	<span class="{.}-title"><xsl:value-of select="../@verdictlabel"/></span>
</xsl:template>



<!-- Graph template -->
<xsl:template name="graph" >
	<xsl:param name="data"/>
	<xsl:param name="graphTitle" />
	
	<xsl:variable name="maxvalueFound">
    	<xsl:for-each select="$data/@value">
	    	<xsl:sort data-type="number" order="descending" />
	   		<xsl:if test="position()=1">
	   			<xsl:value-of select="." />
	   		</xsl:if>
		</xsl:for-each>
    </xsl:variable>
	
	<xsl:if test="$maxvalueFound != 0">
	
		<div class="vertgraph">
	    	<ul class="bars">
    			<ol class="graphTitle"><xsl:value-of select="$graphTitle"/></ol>
    					
    			<xsl:variable name="maxvalue">
	    			<xsl:for-each select="$data/@value">
	    				<xsl:sort data-type="number" order="descending" />
		      				<xsl:if test="position()=1">
	      						<xsl:value-of select="." />
	      					</xsl:if>
	  				</xsl:for-each>
    			</xsl:variable>
    			
    			<!-- There is a bug when $maxvalue is used and not selected more than once -->
    			<xsl:comment>
    				<xsl:copy-of select="$maxvalue" />
    			</xsl:comment>
    					
    			<xsl:variable name="factor">
	    			<xsl:value-of select="100 div $maxvalue" />
    			</xsl:variable>
	    			
    			<xsl:for-each select="$data">
	    			<xsl:variable name="calculatedValue" select="$factor * @value"/>
    				<xsl:if test="@name = 'passed'  and @value != '0' ">
	    				<li class="pass" style="height: {$calculatedValue}px;"><xsl:if test="@value != '0'"><span class="barText"><xsl:value-of select="@value"/></span></xsl:if></li>
    				</xsl:if>
    				<xsl:if test="@name = 'failed'  and @value != '0' ">
	    				<li class="fail" style="height: {$calculatedValue}px;"><xsl:if test="@value != '0'"><span class="barText"><xsl:value-of select="@value"/></span></xsl:if></li>
    				</xsl:if>
					<xsl:if test="@name = 'error'  and @value != '0' ">
						<li class="error" style="height: {$calculatedValue}px;"><xsl:if test="@value != '0'"><span class="barText"><xsl:value-of select="@value"/></span></xsl:if></li>
					</xsl:if>
    				<xsl:if test="@name = 'inconclusive'  and @value != '0' ">
	    				<li class="inconclusive" style="height: {$calculatedValue}px;"><xsl:if test="@value != '0'"><span class="barText"><xsl:value-of select="@value"/></span></xsl:if></li>
    				</xsl:if>
				</xsl:for-each>
    		</ul>
	  	
    		
    	<!-- Graph legend -->
    	<ul class="graphLegend">
	    	<xsl:for-each select="$data">
    			<xsl:if test="@name = 'passed'">
    				<li style="list-style-type:square; color:#A8FC00;"><span class="legendText"><xsl:value-of select="@label"/></span></li>
    			</xsl:if>
    			<xsl:if test="@name = 'failed'">
	    			<li style="list-style-type:square; color:#FF7575;"><span class="legendText"><xsl:value-of select="@label"/></span></li>
    			</xsl:if>
				<xsl:if test="@name = 'error'">
					<li style="list-style-type:square; color:#FF0400;"><span class="legendText"><xsl:value-of select="@label"/></span></li>
				</xsl:if>
    			<xsl:if test="@name = 'inconclusive'">
	    			<li style="list-style-type:square; color:#FE9F00;"><span class="legendText"><xsl:value-of select="@label"/></span></li>
    			</xsl:if>
    		</xsl:for-each>
    	</ul>	
	</div>
	</xsl:if>
</xsl:template>




<xsl:template name="maxValue">
	<xsl:param name="val1" />
	<xsl:param name="val2" />
	
	<xsl:choose>
		<xsl:when test="$val1 > $val2" >
			<xsl:value-of select="$val1" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$val2" />
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>


	


<!-- Graph template -->
<xsl:template name="graphSpecial" >	
	<xsl:param name="data"/>
	<xsl:param name="graphTitle" />
	
	<xsl:variable name="maximumValueCompared1" >
		<xsl:call-template name="maxValue">
			<xsl:with-param name="val1" select="sum($data[@name = 'error']/@value)"/>
			<xsl:with-param name="val2" select="sum($data[@name = 'failed']/@value)" />
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:variable name="maximumValueCompared2" >
		<xsl:call-template name="maxValue">
			<xsl:with-param name="val1" select="sum($data[@name = 'inconclusive']/@value)"/>
			<xsl:with-param name="val2" select="sum($data[@name = 'passed']/@value)" />
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:variable name="maxvalue" >
		<xsl:call-template name="maxValue">
			<xsl:with-param name="val1" select="$maximumValueCompared1"/>
			<xsl:with-param name="val2" select="$maximumValueCompared2" />
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:if test="$maxvalue != 0">
	
		<div class="vertgraph">
	    	<ul class="bars">
    			<ol class="graphTitle"><xsl:value-of select="$graphTitle"/></ol>
    			<xsl:variable name="factor">
	    			<xsl:value-of select="100 div $maxvalue" />
    			</xsl:variable>
	    		
	    	
	    		
	    		<xsl:if test="sum($data[@name = 'passed']/@value) != '0' ">
	    			<li class="pass" style="height: {sum($data[@name = 'passed']/@value) * $factor}px;"><span class="barText"><xsl:value-of select="sum($data[@name = 'passed']/@value)"/></span></li>
    			</xsl:if>
    			<xsl:if test=" sum($data[@name = 'failed']/@value) != '0' ">
	    			<li class="fail" style="height: {sum($data[@name = 'failed']/@value) * $factor}px;"><span class="barText"><xsl:value-of select="sum($data[@name = 'failed']/@value)"/></span></li>
    			</xsl:if>
				<xsl:if test=" sum($data[@name = 'error']/@value) != '0' ">
					<li class="error" style="height: {sum($data[@name = 'error']/@value) * $factor}px;"><span class="barText"><xsl:value-of select="sum($data[@name = 'error']/@value)"/></span></li>
				</xsl:if>
    			<xsl:if test=" sum($data[@name = 'inconclusive']/@value) != '0' ">
	    			<li class="inconclusive" style="height: {sum($data[@name = 'inconclusive']/@value) * $factor}px;"><span class="barText"><xsl:value-of select="sum($data[@name = 'inconclusive']/@value)"/></span></li>
    			</xsl:if>
				
    		</ul>
	  	
    		
    	<!-- Graph legend -->
    	<ul class="graphLegend">
   			<li style="list-style-type:square; color:#A8FC00;"><span class="legendText"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_PASS']"/></span></li>
    		<li style="list-style-type:square; color:#FF7575;"><span class="legendText"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_FAIL']"/></span></li>
			<li style="list-style-type:square; color:#FF0400;"><span class="legendText"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_ERROR']"/></span></li>
	   		<li style="list-style-type:square; color:#FE9F00;"><span class="legendText"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']"/></span></li>
    	</ul>	
	</div>
	</xsl:if>
</xsl:template>



<!-- Timeout -->
<xsl:template match="@timeout" >
	<xsl:choose>
	<xsl:when test=". != 'false'">
		<span class="timeout">(timeout)</span>
	</xsl:when>
	</xsl:choose>
</xsl:template>




<xsl:template match="/">

<!--
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
	   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-->
	   
<html>

  
	<head>
  		<title><xsl:value-of select="document($languagePack)//entry[@key='TITLE']" /></title>
  		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  		<style type="text/css">
  		
  			body {
				font-family:Verdana;
				font-size : 0.8em;	
				color : #5A605B;
				padding:0;
				margin:0;
				width:1100px;
			}

			table {
				text-align:center;	
				width:1024px;
				border-collapse: collapse;
				border: 1px solid #ccc;
				font-size: 0.85em;
			}

			td, th {
				border: 1px solid #ccc;
				text-align: left;
				vertical-align: top;
				padding-left:15px;
				padding-right:15px;
				padding-top:5px;
				padding-bottom:5px;
			}
		
			th {
				color : white;
				background-color:#6699CC
			}

			#page {
				margin:0 0 50px 20px;	
			}

			.pagesection {
				margin-left:30px;	
			}
			
			
			.subpagesection {
				margin-left:20px;
			}
			
			
			h1 {
				text-align:center;
				font-size:2.4em;
			}
			
			.h3 {
				text-decoration:underline;
			}

			h4 {
				margin-bottom:5px;
				font-weight:normal;
				text-decoration:underline;
			}

			.fail, .error, .timeout {	
				color:red;	
				text-decoration:none;
			}
			
			
			.inconclusive {
				color:orange;
				text-decoration:none;
			}

			.pass {
				color:green;	
				text-decoration:none;
			}
			
			
			.fail-title, .error-title {	
				color:red;	
				text-decoration:none;
			}
			
			
			.inconclusive-title {
				color:orange;
				text-decoration:none;
			}

			.pass-title {
				color:green;	
				text-decoration:none;
			}

			tr.VT {
				background-color:#FFFF11;	
			}

			tr.CALL {
				background-color:#FFFF88;	
			}
			
			tr.CALL_BACK {
				background-color:#FFFFAA;
			}

			tr.RETURN {
				background-color:#FFFFCC;	
			}

			tr.VP {
				background-color:#FFFFDD;	
			}
			
			tr.CUSTOMMESSAGE {
			 	background-color:#6699cc;
			 	color : white;
			}
			
			.message {
				font-size:1.2em;
				font-weight:normal;
				font-family: Courier New, Courier, mono;
				color:#9C7C4F;
			}
			
			ul {
				margin:0;
				padding:0;
			}
			
			ul li {
				
				list-style-type:none;
			}
			
			
	.vertgraph {               
	    width: 500px; 
        height: 200px; 
        position: relative; 
        margin-bottom:15px;
        
    }
    .vertgraph ul.bars { 
        width: 349px; 
        height: 160px; 
        margin: 0; 
        padding: 0; 
        border-bottom: dotted 1px #BBBBBB;
        
    }
    .vertgraph ul.bars li {  
        position: absolute; 
        width: 30px; 
        height: 160px; 
        bottom: 40px; 
        padding: 0 !important; 
        margin: 0 !important; 
        text-align: center; 
        color : #787878; 
        line-height: 2.5em;
    }
    
     .vertgraph ol {
    	font-weight: bold;
    	text-align:center;
    }
    

    .vertgraph .bars li.pass{ left: 46px; background-position: 0px bottom !important; background-color:#A8FC00; }
    .vertgraph .bars li.fail { left: 106px; background-position: -28px bottom !important; background-color:#FF7575;}
    .vertgraph .bars li.error { left: 182px; background-position: -56px bottom !important; background-color:#FF0400;}
    .vertgraph .bars li.inconclusive { left: 258px; background-position: -84px bottom !important; background-color:#FE9F00;}

    
    .vertgraph .bars li span.barText {
    	position: absolute;
    	color:black;
    	display: block;
		bottom:-30px;
		

    }
    
    
 	ul.graphLegend  {
 		position:absolute;
 		margin-left:370px;
 		height:100px;
 		top:50px;
		padding-left:20px;
 	}
    	
 	
 	.legendText {
 		color : #5A605B;
 	}
 	
 	.graph1 {
		margin-right:45px;
		margin-top:20px;
 		float:left;
 	}

 	.graph2 {
 		margin-top:20px;
 		float:left;

 	}
			
  		
  		</style>
	</head>
  
  <body>
	
  
  
  

	
	
	<!-- Page title -->	
	<h1><xsl:value-of select="document($languagePack)//entry[@key='TITLE']" /></h1>



	<xsl:variable name="starttime">
	  <xsl:for-each select="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN/SCHEDULE/@startime">
	    <xsl:sort data-type="number" order="ascending" />
	      <xsl:if test="position()=1">
	      <xsl:value-of select="../@startdate" />
	      </xsl:if>
	  </xsl:for-each>
	</xsl:variable>
	
	<xsl:variable name="endtime">
	  <xsl:for-each select="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN/SCHEDULE/@endtime">
	    <xsl:sort data-type="number" order="descending" />
	     <xsl:if test="position()=1">
	      <xsl:value-of select="../@enddate" /> 
	      </xsl:if>
	  </xsl:for-each>
	</xsl:variable>
	


    
    <div id="page">
    
    	

    	<!-- ************************ GLOBAL SUMMARY ************************ -->
		<h2><xsl:value-of select="document($languagePack)//entry[@key='MAIN_GLOBAL_SUMMARY']" /></h2>
		<div class="pagesection">
			<ul>
				<li><xsl:value-of select="document($languagePack)//entry[@key='FUNCTIONAL_DATA_DESIGN']" /> Web services - Full</li>
				<li><xsl:value-of select="document($languagePack)//entry[@key='PRODUCT_VERSION']" />IBM Rational Tester for SOA Quality version 8.2</li>
				<li><xsl:value-of select="document($languagePack)//entry[@key='START_TIME']" /><xsl:value-of select="$starttime"/></li>
				<li><xsl:value-of select="document($languagePack)//entry[@key='END_TIME']" /><xsl:value-of select="$endtime"/></li>
				<li><xsl:value-of select="document($languagePack)//entry[@key='TOTAL_NUMBER_TESTS']" /><xsl:value-of select="count(/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN/SCHEDULE/GROUP/USER/TEST)"/></li>
				<li><xsl:value-of select="document($languagePack)//entry[@key='TOTAL_NUMBER_VPS']" /><xsl:value-of select="count(/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN/SCHEDULE/GROUP/USER/TEST/CALL/ANSWER/VP)"/></li>
				<li><xsl:value-of select="document($languagePack)//entry[@key='TOTAL_NUMBER_DEFECTS']" /><xsl:value-of select="count(/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN/SCHEDULE/GROUP/USER/TEST//DEFECT)"/></li>
			</ul>
			
			
			
			
			<!-- Create Bar graph for all tests -->
			<xsl:if test="count(/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN/SCHEDULE/GROUP/USER/TEST) > 0">
				<div class="graph1">
				<xsl:call-template name="graphSpecial">
					<xsl:with-param name="data" select="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/TEST_RESULTS/STATUS"/>
					<xsl:with-param name="graphTitle" select="document($languagePack)//entry[@key='TEST_VERDICTS']" />
				</xsl:call-template>
				</div>
			</xsl:if>
			
			
			
			
			
			
			<!-- Create Bar graph for all vps -->
			<xsl:if test="count(/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN/SCHEDULE/GROUP/USER/TEST/CALL/ANSWER/VP) > 0">
				<div class="graph2">
				<xsl:call-template name="graph">
					<xsl:with-param name="data" select="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/VP_RESULTS/STATUS"/>
					<xsl:with-param name="graphTitle" select="document($languagePack)//entry[@key='VP_VERDICTS']" />
				</xsl:call-template>
				</div>
			</xsl:if>

			
			<div style="clear:both" />
			
			
		</div>
		
		
		
		
		
		
		
		
		
<xsl:choose>
	<xsl:when test="count(/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN) > 1">
		<!-- ************************ RUN SUMMARY ************************ -->
		<h2><xsl:value-of select="document($languagePack)//entry[@key='MAIN_RUN_SUMMARY']" /></h2>
		<div class="pagesection">
			<table>
				<tr>
					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_RUN_NAME']" /></th>
					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_START_TIME']" /></th>
					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_END_TIME']" /></th>
					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_VERDICT']" /></th>
				</tr>
				
				<xsl:for-each select="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN">
				<tr>
					<xsl:if test="(position() mod 2 = 1)">
						<xsl:attribute name="bgcolor">#EEEEFF</xsl:attribute>
					</xsl:if>
					<td><xsl:value-of select="@name"/></td>
					<td><xsl:value-of select="SCHEDULE/@startdate"/></td>
					<td><xsl:value-of select="SCHEDULE/@enddate"/></td>
					<td><xsl:apply-templates select="@verdict" mode="run"/></td>
				</tr>
				</xsl:for-each>
			</table>
		
		
		<!-- Loop for runs -->
		<xsl:for-each select="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN">
		<div class="subpagesection">
	    
			<!-- Run -->
	    	<h3><span class="h3"><a name="{@name}">Run : </a><xsl:value-of select="@name"/></span></h3>
			<ul>
				<li><xsl:value-of select="document($languagePack)//entry[@key='TOTAL_NUMBER_TESTS']" /><xsl:value-of select="count(child::SCHEDULE/GROUP/USER/TEST)"/></li>
				<li><xsl:value-of select="document($languagePack)//entry[@key='TOTAL_NUMBER_VPS']" /><xsl:value-of select="count(child::SCHEDULE/GROUP/USER/TEST/CALL/ANSWER/VP)"/></li>
				
				<xsl:variable name="selectedRun"><xsl:value-of select="@name"/></xsl:variable>
				<xsl:for-each select="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN">
						<xsl:if test="@name = $selectedRun">
							<li><xsl:value-of select="document($languagePack)//entry[@key='TOTAL_NUMBER_DEFECTS']" /><xsl:value-of select="count(.//DEFECT)"/></li>
						</xsl:if>
				</xsl:for-each>
			</ul>
			
			<!-- Create Bar graph for all tests by Run -->
			<xsl:if test="count(child::SCHEDULE/GROUP/USER/TEST) > 0">
				<div class="graph1">
				<xsl:call-template name="graphSpecial">
					<xsl:with-param name="data" select="TEST_RESULTS/STATUS"/>
					<xsl:with-param name="graphTitle" select="document($languagePack)//entry[@key='TEST_VERDICTS']" />
				</xsl:call-template>
				</div>
			</xsl:if>
				
			<!-- Create Bar graph for all vps by Run -->
			<xsl:if test="count(child::SCHEDULE/GROUP/USER/TEST/CALL/ANSWER/VP) > 0">
				<div class="graph2">
				<xsl:call-template name="graph">
					<xsl:with-param name="data" select="VP_RESULTS/STATUS"/>
					<xsl:with-param name="graphTitle" select="document($languagePack)//entry[@key='VP_VERDICTS']" />
				</xsl:call-template>
				</div>
			</xsl:if>
			
			<div style="clear:both" />
			
			
			
			
			
			
			
		
 			<!--  Test by Run part -->
 			<xsl:if test="count(child::SCHEDULE/GROUP/USER/TEST) > 0" >
	    	<h4><xsl:value-of select="document($languagePack)//entry[@key='SUB_TEST_VERDICTS']" /></h4>
	   		<table>
	    		<tr>
	      			<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_TEST_NAME']" /></th>
	      			<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_START_TIME']" /></th>
	      			<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_END_TIME']" /></th>
	      				      			
	      			
	      			<!--  Defect number column is only displayed if at least one defect exists in the entire FUNCTIONAL_DATA -->
	      			<xsl:if test="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA//DEFECT ">
	      				<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_DEFECT_NUMBER']" /></th>
	      			</xsl:if>
	      			<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_VERDICT']" /></th>
	      			
	    		</tr>
				<xsl:for-each select="child::SCHEDULE/GROUP/USER/TEST">
				<tr>
				<xsl:if test="(position() mod 2 = 1)">
					<xsl:attribute name="bgcolor">#EEEEFF</xsl:attribute>
				</xsl:if>
	      			<td><xsl:value-of select="@name"/></td>
	      			<td><xsl:value-of select="@startdate"/></td>
	      			<td><xsl:value-of select="@enddate"/></td>

	      			<!--  Defect number column is only displayed if at least one defect exists -->
					<xsl:if test="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA//DEFECT">
  						<td><xsl:value-of select="count(.//DEFECT)"/></td>
					</xsl:if>
					<td><xsl:apply-templates select="@verdict" mode="all"/></td>
	    		</tr>
				</xsl:for-each>
	    	</table>
	    	</xsl:if>
			<!--  End Test by Run part -->
			
		

	    	<!--  VP by Run part -->	
	    	<xsl:if test="count(child::SCHEDULE/GROUP/USER/TEST/CALL/ANSWER/VP) > 0 ">	
	    	<h4><xsl:value-of select="document($languagePack)//entry[@key='SUB_VP_VERDICTS']" /></h4>
	    	<table>
	    		<tr>
	      			<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_VP_NAME']" /></th>
	      			<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_TIMESTAMP']" /></th>
	      			<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_VERDICT']" /></th>
	    		</tr>
				<xsl:for-each select="child::SCHEDULE/GROUP/USER/TEST/CALL/ANSWER/VP">
				<tr>
				<xsl:if test="(position() mod 2 = 1)">
					<xsl:attribute name="bgcolor">#EEEEFF</xsl:attribute>
				</xsl:if>
	      			<td><xsl:value-of select="@name"/></td>
	      			<td><xsl:value-of select="@datestamp"/></td>
	      			<td><xsl:apply-templates select="@verdict" mode="all"/></td>
	    		</tr>
				</xsl:for-each>
	    	</table>
	    	</xsl:if>
	    	<!--  End VP by Run part -->

		</div>
		</xsl:for-each>
		<!-- End Loop for runs -->
	</div>
	</xsl:when>
</xsl:choose>
	
		<!-- ************************ TEST SUMMARY ************************ -->
    	<h2><xsl:value-of select="document($languagePack)//entry[@key='MAIN_TEST_SUMMARY']" /></h2>
    	
    	<div class="pagesection">
    		<table>
    			<tr>
	      			<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_TEST_NAME']" /></th>
      				<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_START_TIME']" /></th>
      				<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_END_TIME']" /></th>
      				<!--  Defect number column is only displayed if at least one defect exists in the entire FUNCTIONAL_DATA -->
	      			<xsl:if test="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA//DEFECT ">
	      				<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_DEFECT_NUMBER']" /></th>
	      			</xsl:if>
      				<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_VERDICT']" /></th>
    			</tr>
    			<xsl:for-each select="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN/SCHEDULE/GROUP/USER/TEST">
    			
    			
    			
    			
    				<tr>
	   				<xsl:if test="(position() mod 2 = 1)">
						<xsl:attribute name="bgcolor">#EEEEFF</xsl:attribute>
					</xsl:if>
    		  			<td><xsl:value-of select="@name"/></td>
      					<td><xsl:value-of select="@startdate"/></td>
      					<td><xsl:value-of select="@enddate"/></td>
      					<!--  Defect number column is only displayed if at least one defect exists -->
						<xsl:if test="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA//DEFECT">
  							<td><xsl:value-of select="count(.//DEFECT)"/></td>
						</xsl:if>
      					<td><xsl:apply-templates select="@verdict" mode="all"/></td>
    				</tr>
    				</xsl:for-each>
    		
    			
    		</table>
    	
    	
   			<!-- Loop for Tests -->
		    <xsl:for-each select="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN/SCHEDULE/GROUP/USER/TEST">
			<div class="subpagesection">
		    	<h3><span class="h3"><a name="{@linkid}"><xsl:value-of select="document($languagePack)//entry[@key='SUB_TEST']" /></a> <xsl:value-of select="@name"/></span>(<xsl:apply-templates select="@verdict" mode="nolinktitle"/>)</h3>
					<ul>
						<li><xsl:value-of select="document($languagePack)//entry[@key='TOTAL_NUMBER_VPS']" /><xsl:value-of select="count(child::CALL/ANSWER/VP)"/></li>
						<li><xsl:value-of select="document($languagePack)//entry[@key='TOTAL_NUMBER_CALLS']" /><xsl:value-of select="count(child::CALL)"/></li>
						<li><xsl:value-of select="document($languagePack)//entry[@key='TOTAL_NUMBER_RETURNS']" /><xsl:value-of select="count(child::CALL/ANSWER)"/></li>
						
						<xsl:variable name="numberOfDefects"><xsl:value-of select="count(.//DEFECT)"/></xsl:variable>
						
						<li><xsl:value-of select="document($languagePack)//entry[@key='TOTAL_NUMBER_DEFECTS']" /><xsl:value-of select="$numberOfDefects"/></li>
						<xsl:if test="$numberOfDefects > 0">
							<li><xsl:value-of select="document($languagePack)//entry[@key='LIST_DEFECTS']" />
								<xsl:for-each select=".//DEFECT">
									<xsl:choose>
										<xsl:when test="position()=last()"><a href="{@uri}" alt="" target="_blank" ><xsl:value-of select="@num"/></a></xsl:when>
										<xsl:otherwise><a href="{@uri}" alt="" target="_blank" ><xsl:value-of select="@num"/></a>&#44;</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</li>
						</xsl:if>
					</ul>
				
					
					<!-- Create Bar graph for all vps -->
					<xsl:if test="count(child::CALL/ANSWER/VP) > 0" >
						<div class="graph1">
							<xsl:call-template name="graph">
								<xsl:with-param name="data" select="VP_RESULTS/STATUS"/>
								<xsl:with-param name="graphTitle" select="document($languagePack)//entry[@key='VP_VERDICTS']" />
							</xsl:call-template>
						</div>
					</xsl:if>
							
					<!-- Create Bar graph for all calls -->
					<xsl:if test="count(child::CALL) > 0" >
						<div class="graph2">
							<xsl:call-template name="graph">
								<xsl:with-param name="data" select="CALL_RESULTS/STATUS"/>
								<xsl:with-param name="graphTitle" select="document($languagePack)//entry[@key='CALL_VERDICTS']" />
							</xsl:call-template>
						</div>
					</xsl:if>
			
			
					<!-- Create Bar graph for all returns -->
					<xsl:if test="count(child::CALL/ANSWER) > 0" >
						<div class="graph2">
							<xsl:call-template name="graph">
								<xsl:with-param name="data" select="ANSWER_RESULTS/STATUS"/>
								<xsl:with-param name="graphTitle" select="document($languagePack)//entry[@key='RETURNS_VERDICTS']" />
							</xsl:call-template>
						</div>
					</xsl:if>
					<div style="clear:both" />
				
			
					
					
					
    
				<!-- VPs by Test -->
				<xsl:if test="count(child::CALL/ANSWER/VP) > 0" >
			    <h4><xsl:value-of select="document($languagePack)//entry[@key='SUB_VP_VERDICTS']" /></h4>
    			<table>
    				<tr>
      					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_VP_NAME']" /></th>
      					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_TIMESTAMP']" /></th>
      					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_VERDICT']" /></th>
    				</tr>
					<xsl:for-each select="child::CALL/ANSWER/VP">
					<tr>
					<xsl:if test="(position() mod 2 = 1)">
						<xsl:attribute name="bgcolor">#EEEEFF</xsl:attribute>
					</xsl:if>
      					<td><xsl:value-of select="@name"/></td>
      					<td><xsl:value-of select="@datestamp"/></td>
      					<td><xsl:apply-templates select="@verdict" mode="all"/></td>
    				</tr>
					</xsl:for-each>
    			</table>
    			</xsl:if>
    			<!-- End VPs by Test -->
    
    
    			<!-- Calls by Test -->
    			<xsl:if test="count(child::CALL) > 0 ">
    		    <h4><xsl:value-of select="document($languagePack)//entry[@key='SUB_CALL_VERDICTS']" /></h4>
    			<table>
    				<tr>
      					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_CALL_NAME']" /></th>
      					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_TIMESTAMP']" /></th>
      					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_VERDICT']" /></th>
    				</tr>
					<xsl:for-each select="child::CALL">
					<tr>
					<xsl:if test="(position() mod 2 = 1)">
						<xsl:attribute name="bgcolor">#EEEEFF</xsl:attribute>
					</xsl:if>
      					<td><xsl:value-of select="@name"/></td>
      					<td><xsl:value-of select="@datestamp"/></td>
      					<td><xsl:apply-templates select="@verdict" mode="all"/></td>
    				</tr>
					</xsl:for-each>
    			</table>
    			</xsl:if>
    			<!-- End Calls by Test -->
    
    
    
    			<!-- Returns by Test -->
    			<xsl:if test="count(child::CALL/ANSWER) > 0" >
    		    <h4><xsl:value-of select="document($languagePack)//entry[@key='SUB_RETURN_VERDICTS']" /></h4>
    			<table>
    				<tr>
      					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_RETURN_NAME']" /></th>
      					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_TIMESTAMP']" /></th>
      					<th><xsl:value-of select="document($languagePack)//entry[@key='TABLE_VERDICT']" /></th>
    				</tr>
					<xsl:for-each select="child::CALL/ANSWER">
					<tr>
					<xsl:if test="(position() mod 2 = 1)">
						<xsl:attribute name="bgcolor">#EEEEFF</xsl:attribute>
					</xsl:if>
      					<td><xsl:value-of select="@name"/></td>
      					<td><xsl:value-of select="@datestamp"/></td>
      					<td><xsl:apply-templates select="@verdict" mode="all"/></td>
    				</tr>
					</xsl:for-each>
    			</table>
    			</xsl:if>
				<!-- End Returns by Test -->
    		</div>
			</xsl:for-each>
		</div>
	
	
		<!-- ************************ TEST LOG ************************ -->
		<h2><xsl:value-of select="document($languagePack)//entry[@key='MAIN_TEST_LOG']" /></h2>
		<div class="pagesection">
			<table>
			
			<xsl:for-each select="/FUNCTIONAL_DATA/SOA_FUNCTIONAL_DATA/RUN/SCHEDULE/GROUP/USER">
			
				<!-- VT -->
				<tr class="VT">
					<td><a name="{@linkid}">VT</a></td>
					<td colspan="2"><xsl:value-of select="@datestamp"/>&#160;<xsl:apply-templates select="@verdict" mode="nolink"/>&#160;<xsl:value-of select="@name"/>&#160;<xsl:value-of select="@hostname"/></td>
				</tr>
				<!-- End VT -->
			
				
				<!--
				<xsl:if test="//child::TEST/*[name()='CUSTOM_MSG']">
					<tr class="CUSTOMMESSAGE">
						<td>CUSTOM MESSAGE</td>
						<td colspan="2"><xsl:value-of select="parent::TEST/CUSTOM_MSG/@value"/></td>
					</tr>
				</xsl:if>
				
				<xsl:for-each select="preceding::self">
				<tr class="CUSTOMMESSAGE">
						<td>CUSTOM MESSAGE</td>
						<td colspan="2"><xsl:value-of select="parent::TEST/CUSTOM_MSG/@value"/></td>
					</tr>
				</xsl:for-each>
				
				-->
				

				
				
				
				
				
				<xsl:for-each select="TEST/child::*">
			
	
				
	
				 
				<xsl:if test="local-name()='CUSTOM_MSG'">
					<tr class="CUSTOMMESSAGE">
						<td>CUSTOM MESSAGE</td>
						<td colspan="2"><xsl:value-of select="@value"/></td>
					</tr>
				</xsl:if>
				
				
				
				
				<!-- Call -->
				<xsl:if test="local-name()='CALL'">
					
				
				<tr class="CALL">
					<td><a name="{@linkid}">CALL</a></td>
					<td colspan="2"><xsl:value-of select="@datestamp"/>&#160;<xsl:apply-templates select="@verdict" mode="nolink"/>&#160;<xsl:apply-templates select="@timeout" />&#160;<xsl:value-of select="@name"/></td>
				</tr>
				
				
				<xsl:if test="(../@path != ' ') and (../@path != '')">
					<tr class="CALL">
						<td></td>
						<td colspan="2">
							<xsl:value-of select="document($languagePack)//entry[@key='PATH']" />&#160;<xsl:value-of select="../@path"/>&#160;<xsl:value-of select="@path"/>
						</td>
					</tr>
				</xsl:if>
				
				<tr class="CALL">
					<td></td>
					<td colspan="2"><span class="message"><pre><xsl:value-of select="@sent"/></pre></span></td>
				</tr>
				
				
				<!--  CUSTOM MSG on CALL -->
				<xsl:for-each select="child::CUSTOM_MSG">
					<tr class="CUSTOMMESSAGE">
						<td>CUSTOM MESSAGE</td>
						<td colspan="2"><xsl:value-of select="@value"/></td>
					</tr>
				</xsl:for-each>
				
				
		
				<!-- Return -->
				<xsl:for-each select="child::ANSWER">
					<tr class="RETURN">
						<td><a name="{@linkid}">RETURN</a></td>
						<td colspan="2"><xsl:value-of select="@datestamp"/>&#160;<xsl:apply-templates select="@verdict" mode="nolink"/>&#160;<xsl:apply-templates select="@timeout" />&#160;<xsl:value-of select="@name"/></td>
					</tr>
					<tr class="RETURN">
						<td></td>
						<td colspan="2"><xsl:value-of select="document($languagePack)//entry[@key='VALUES']" /><span class="message"><pre><xsl:value-of select="@value"/></pre></span></td>
					</tr>
				
					<!--  CUSTOM MSG on ANSWER -->
					<xsl:for-each select="child::CUSTOM_MSG">
						<tr class="CUSTOMMESSAGE">
							<td>CUSTOM MESSAGE</td>
							<td colspan="2"><xsl:value-of select="@value"/></td>
						</tr>
					</xsl:for-each>
				
				
				
			
					<!-- VP -->
					<xsl:for-each select="child::VP">
						<tr class="VP">
							<td><a name="{@linkid}">VP</a></td>
							<td colspan="2">VP <xsl:value-of select="@datestamp"/>&#160;<xsl:apply-templates select="@verdict" mode="nolink"/>&#160;<xsl:value-of select="@name"/></td>
						</tr>
						<tr class="VP">
							<td></td>
							<td><xsl:value-of select="document($languagePack)//entry[@key='TABLE_EXPECTED']" /></td>
							<td><xsl:value-of select="document($languagePack)//entry[@key='TABLE_ACTUAL']" /></td>
						</tr>
						<tr class="VP">
							<td></td>
							<td><span class="message"><pre><xsl:value-of select="child::EXPECTED/@value"/></pre></span></td>
							<td><span class="message"><pre><xsl:value-of select="child::RECEIVED/@value"/></pre></span></td>
						</tr>
					
						<!--  CUSTOM MSG on VP -->
						<xsl:for-each select="child::CUSTOM_MSG">
							<tr class="CUSTOMMESSAGE">
								<td>CUSTOM MESSAGE</td>
								<td colspan="2"><xsl:value-of select="@value"/></td>
							</tr>
						</xsl:for-each>
					</xsl:for-each>
					<!-- End VP -->	
			
				</xsl:for-each>
				<!-- End Return -->
		
				</xsl:if>
				<!-- End Call -->
				
		</xsl:for-each>
		
		
		
	
	
	
				<!-- Call Back -->
				<xsl:for-each select="child::TEST/CALL_BACK">
					<tr class="CALL_BACK">
						<td><a name="{@linkid}">CALLBACK</a></td>
						<td colspan="2"><xsl:value-of select="@datestamp"/>&#160;<xsl:apply-templates select="@verdict" mode="nolink"/>&#160;<xsl:value-of select="@name"/></td>
					</tr>
					<tr class="CALL_BACK">
						<td></td>
						<td colspan="2"><xsl:value-of select="document($languagePack)//entry[@key='SENT']" /><span class="message"><pre><xsl:value-of select="@sent"/></pre></span></td>
					</tr>
								
					<!--  CUSTOM MSG on call back -->
					<xsl:for-each select="child::CUSTOM_MSG">
						<tr class="CUSTOMMESSAGE">
							<td>CUSTOM MESSAGE</td>
							<td colspan="2"><xsl:value-of select="@value"/></td>
						</tr>
					</xsl:for-each>
				</xsl:for-each>
				<!-- End Call Back -->
		
	</xsl:for-each>
	
			</table>
	
		</div>
    </div>
    
  </body>
  </html>
</xsl:template>






</xsl:stylesheet>