<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" >
<xsl:output method="xml" indent="yes"/>

<!-- WARNING : Use to load language pack DO NOT REMOVE -->
<xsl:param name="languagePack" select="default"/>




<!-- Manage SOA_FUNCTIONAL_DATA node -->
<xsl:template match="FUNCTIONAL_DATA" >
	<xsl:call-template name="setVPsGraphData" />
	<xsl:call-template name="setTESTsGraphData" />
</xsl:template>

<!-- Manage RUN node -->
<xsl:template match="RUN" >
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeVerdict" />
	<xsl:call-template name="setNodeNameAndDescription" />
	<xsl:call-template name="setVPsGraphData"/>
	<xsl:call-template name="setTESTsGraphData" />
	<xsl:call-template name="setCallsGraphData" />
	<xsl:call-template name="setAnswersGraphData" />
</xsl:template>

<!-- Manage SCHEDULE node -->
<xsl:template match="SCHEDULE" >
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeVerdict"/>
	<xsl:call-template name="setNodeNameAndDescription" />
	<xsl:call-template name="setNodeTimeAndDates" />
</xsl:template>

<!-- Manage GROUP node -->
<xsl:template match="GROUP" >
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeVerdict" />
	<xsl:call-template name="setNodeNameAndDescription" />
</xsl:template>

<!-- Manage USER node -->
<xsl:template match="USER" >
	<xsl:call-template name="setNodeVerdict" />
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeNameAndDescription" />
	<xsl:call-template name="setNodeTimestampAndDatestamp" />
	<xsl:call-template name="setNodeHostname" />
</xsl:template>

<!-- Manage TEST node -->
<xsl:template match="TEST" >
	<xsl:call-template name="setNodeVerdict" />
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeNameAndDescription" />
	<xsl:call-template name="setNodeTimeAndDates" />
	<xsl:call-template name="setNodePath" />
	<xsl:call-template name="setVPsGraphData" />
	<xsl:call-template name="setCallsGraphData" />
	<xsl:call-template name="setAnswersGraphData" />
</xsl:template>


<!-- Manage DEFECT node -->
<xsl:template match="DEFECT" >
	<xsl:call-template name="setNodeEvent" />
	<xsl:call-template name="setNodeDefectNumber" />
	<xsl:call-template name="setNodeDefectUri" />
	
	<xsl:call-template name="setNodeRunId" />
	<xsl:call-template name="setNodeTestId" />>

</xsl:template>


<!-- Manage CALL node -->
<xsl:template match="CALL" >
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeVerdictFromTPTP" />
	<xsl:call-template name="setNodeTimeout" />
	<xsl:call-template name="setNodeconnectionTime" />
	<xsl:call-template name="setNodePath" />
	<xsl:call-template name="setNodeNameAndDescription" />
	<xsl:call-template name="setNodeTimestampAndDatestamp" />
	<xsl:call-template name="setNodeSent" />
</xsl:template>

<!-- Manage CUSTOM_MSG node -->
<xsl:template match="CUSTOM_MSG" >
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeValue" />
</xsl:template>


<!-- Manage ANSWER node -->
<xsl:template match="ANSWER" >
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeVerdictFromTPTP" />
	<xsl:call-template name="setNodeNameAndDescription" />
	<xsl:call-template name="setNodeTimeout" />
	<xsl:call-template name="setNodeTimestampAndDatestamp" />
	<xsl:call-template name="setNodeValue" />
	
</xsl:template>

<!-- Manage VP node -->
<xsl:template match="VP" >
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeVerdictFromTPTP" />
	<xsl:call-template name="setNodeNameAndDescription" />	
	<xsl:call-template name="setNodeTimestampAndDatestamp" />
	<xsl:call-template name="setNodeType" />
</xsl:template>

<!-- Manage EXPECTED node -->
<xsl:template match="EXPECTED" >
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeValue" />
</xsl:template>

<!-- Manage RECEIVED node -->
<xsl:template match="RECEIVED" >
	<xsl:call-template name="setNodeLinkId" />
	<xsl:call-template name="setNodeValue" />
</xsl:template>


<!--  Set Node Event -->
<xsl:template name="setNodeEvent">
	<xsl:attribute name="event">
		<xsl:value-of select="@vent" />
	</xsl:attribute>
</xsl:template>


<!--  Set Node Defect Number -->
<xsl:template name="setNodeDefectNumber">
	<xsl:attribute name="num">
		<xsl:value-of select="@num" />
	</xsl:attribute>
</xsl:template>


<!--  Set Node URI -->
<xsl:template name="setNodeDefectUri">
	<xsl:attribute name="uri">
		<xsl:value-of select="@uri" />
	</xsl:attribute>
</xsl:template>

<!--  Set Node ParentNodeType -->
<xsl:template name="setNodeRunId">
	<xsl:attribute name="RunId">
		<xsl:value-of select="generate-id(ancestor::RUN)" />
	</xsl:attribute>
</xsl:template>

<!--  Set Node ParentNodeId -->
<xsl:template name="setNodeTestId">
	<xsl:attribute name="TestId">
		<xsl:value-of select="generate-id(ancestor::TEST)" />
	</xsl:attribute>
</xsl:template>


<!-- Set Node Id -->
<xsl:template name="setNodeLinkId">
	<xsl:attribute name="linkid">
		<xsl:value-of select="generate-id(.)" />
	</xsl:attribute>
</xsl:template>

<!-- Set Node Verdict  - Verdict is calculated depending on the status of the last node -->
<xsl:template name="setNodeVerdict">
	<xsl:attribute name="verdict">
	<xsl:choose>
		<xsl:when test="count(descendant::VP) > 0">
			<xsl:choose>
	  			<xsl:when test="count(descendant::VP[@verdict='error']) >= 1">error</xsl:when>	
  				<xsl:when test="count(descendant::VP[@verdict='fail']) >= 1">fail</xsl:when>	
  				<xsl:when test="count(descendant::VP[@verdict='inconclusive']) >= 1">inconclusive</xsl:when>	
  				<xsl:when test="count(descendant::VP[@verdict='pass']) >= 1">pass</xsl:when>
			</xsl:choose>
		</xsl:when>
		<xsl:when test="count(descendant::ANSWER) >0">
			<xsl:choose>
	  			<xsl:when test="count(descendant::ANSWER[@verdict='error']) >= 1">error</xsl:when>	
  				<xsl:when test="count(descendant::ANSWER[@verdict='fail']) >= 1">fail</xsl:when>	
  				<xsl:when test="count(descendant::ANSWER[@verdict='inconclusive']) >= 1">inconclusive</xsl:when>	
  				<xsl:when test="count(descendant::ANSWER[@verdict='pass']) >= 1">pass</xsl:when>
			</xsl:choose>
		</xsl:when>
		<xsl:when test="count(descendant::CALL) >0">
			<xsl:choose>
	  			<xsl:when test="count(descendant::CALL[@verdict='error']) >= 1">error</xsl:when>	
  				<xsl:when test="count(descendant::CALL[@verdict='fail']) >= 1">fail</xsl:when>	
  				<xsl:when test="count(descendant::CALL[@verdict='inconclusive']) >= 1">inconclusive</xsl:when>	
  				<xsl:when test="count(descendant::CALL[@verdict='pass']) >= 1">pass</xsl:when>
			</xsl:choose>
		</xsl:when>
	</xsl:choose>
	
	
		
	</xsl:attribute>
	<xsl:attribute name="verdictlabel">
	<xsl:choose>
		<xsl:when test="count(descendant::VP) > 0">
			<xsl:choose>
	  			<xsl:when test="count(descendant::VP[@verdict='error']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_ERROR']" /></xsl:when>	
  				<xsl:when test="count(descendant::VP[@verdict='fail']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_FAIL']" /></xsl:when>	
  				<xsl:when test="count(descendant::VP[@verdict='inconclusive']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']" /></xsl:when>	
  				<xsl:when test="count(descendant::VP[@verdict='pass']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_PASS']" /></xsl:when>
			</xsl:choose>
		</xsl:when>
		<xsl:when test="count(descendant::ANSWER) > 0" >
			<xsl:choose>
	  			<xsl:when test="count(descendant::ANSWER[@verdict='error']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_ERROR']" /></xsl:when>	
  				<xsl:when test="count(descendant::ANSWER[@verdict='fail']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_FAIL']" /></xsl:when>	
  				<xsl:when test="count(descendant::ANSWER[@verdict='inconclusive']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']" /></xsl:when>	
  				<xsl:when test="count(descendant::ANSWER[@verdict='pass']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_PASS']" /></xsl:when>
			</xsl:choose>
		</xsl:when>
		<xsl:when test="count(descendant::CALL) >0">
			<xsl:choose>
	  			<xsl:when test="count(descendant::CALL[@verdict='error']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_ERROR']" /></xsl:when>	
  				<xsl:when test="count(descendant::CALL[@verdict='fail']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_FAIL']" /></xsl:when>	
  				<xsl:when test="count(descendant::CALL[@verdict='inconclusive']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']" /></xsl:when>	
  				<xsl:when test="count(descendant::CALL[@verdict='pass']) >= 1"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_PASS']" /></xsl:when>
			</xsl:choose>
		</xsl:when>
	</xsl:choose>
	
	  		
	
	</xsl:attribute>
</xsl:template>




<!-- !!! Set Node Verdict from TPTP Test Log. !!! -->
<xsl:template name="setNodeVerdictFromTPTP">
	<xsl:attribute name="verdict">
		<xsl:choose>
			<xsl:when test="@verdict"><xsl:value-of select="@verdict" /></xsl:when>
			<xsl:when test="@status"><xsl:value-of select="@status" /></xsl:when>
		</xsl:choose>
	</xsl:attribute>
	<xsl:attribute name="verdictlabel">
		<xsl:choose>
	  		<xsl:when test="@verdict='error'"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_ERROR']" /></xsl:when>	
  			<xsl:when test="@verdict='fail'"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_FAIL']" /></xsl:when>	
  			<xsl:when test="@verdict='inconclusive'"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']" /></xsl:when>	
  			<xsl:when test="@verdict='pass'"><xsl:value-of select="document($languagePack)//entry[@key='STATUS_PASS']" /></xsl:when>
		</xsl:choose>
	</xsl:attribute>
</xsl:template>

<!-- Set Node Name -->
<xsl:template name="setNodeNameAndDescription">
	<xsl:attribute name="name" ><xsl:value-of select="@name" /> </xsl:attribute>
	<xsl:attribute name="description" ><xsl:value-of select="@description" /> </xsl:attribute>
</xsl:template>


<!-- Set Time and Dates (Start and End) -->
<xsl:template name="setNodeTimeAndDates">
	<xsl:attribute name="startdate" ><xsl:value-of select="@startdate" /> </xsl:attribute>
	<xsl:attribute name="enddate" ><xsl:value-of select="@enddate" /> </xsl:attribute>
	<xsl:attribute name="startime" ><xsl:value-of select="@startime" /> </xsl:attribute>
	<xsl:attribute name="endtime" ><xsl:value-of select="@endtime" /> </xsl:attribute>
</xsl:template>


<!-- Set Timestamp and Dates (Start and End) -->
<xsl:template name="setNodeTimestampAndDatestamp">
	<xsl:attribute name="datestamp" ><xsl:value-of select="@datestamp" /> </xsl:attribute>
	<xsl:attribute name="timestamp" ><xsl:value-of select="@timestamp" /> </xsl:attribute>
</xsl:template>

<!-- Set connectionTime -->
<xsl:template name="setNodeconnectionTime">
	<xsl:attribute name="connectionTime" ><xsl:value-of select="@connectionTime" /> </xsl:attribute>
</xsl:template>



<!-- Set hostname -->
<xsl:template name="setNodeHostname">
	<xsl:attribute name="hostname" ><xsl:value-of select="@hostname" /> </xsl:attribute>
</xsl:template>


<!-- Set path -->
<xsl:template name="setNodePath">
	<xsl:attribute name="path" ><xsl:value-of select="@path" /> </xsl:attribute>
</xsl:template>

<!-- Set Timeout -->
<xsl:template name="setNodeTimeout">
	<xsl:attribute name="timeout" ><xsl:value-of select="@timeout" /> </xsl:attribute>
</xsl:template>


<!-- Set Value -->
<xsl:template name="setNodeValue">
	<xsl:attribute name="value" ><xsl:value-of select="@value" /> </xsl:attribute>
</xsl:template>

<!-- Set sent -->
<xsl:template name="setNodeSent">
	<xsl:attribute name="sent" ><xsl:value-of select="@sent" /> </xsl:attribute>
</xsl:template>


<!-- Set Type -->
<xsl:template name="setNodeType">
	<xsl:attribute name="type" ><xsl:value-of select="@type" /> </xsl:attribute>
</xsl:template>



<!-- FAIRE AVEC LES VARIABLES MAINTENANT !!!! -->


<!-- set Test Graph Data -->
<xsl:template name="setTESTsGraphData">
	<TEST_RESULTS>
		<xsl:for-each select="descendant::TEST">
			<xsl:choose>
				<xsl:when test="count(descendant::VP) > 0">
					<STATUS name="error"  label="{document($languagePack)//entry[@key='STATUS_ERROR']}"  value="{count(.[count(descendant::VP[@verdict='error']) >= 1])}" />
					<STATUS name="failed"  label="{document($languagePack)//entry[@key='STATUS_FAIL']}"  value="{count(.[(count(descendant::VP[@verdict='fail']) >= 1) and  (count(descendant::VP[@verdict='error']) = 0)           ])}" />
					<STATUS name="inconclusive"  label="{document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']}"  value="{count(.[(count(descendant::VP[@verdict='inconclusive']) >= 1) and  (count(descendant::VP[@verdict='error']) = 0)    and  (count(descendant::VP[@verdict='fail']) = 0)           ])}" />
					<STATUS name="passed"  label="{document($languagePack)//entry[@key='STATUS_PASS']}"  value="{count(.[(count(descendant::VP[@verdict='pass']) >= 1) and  (count(descendant::VP[@verdict='error']) = 0)    and  (count(descendant::VP[@verdict='fail']) = 0)    and  (count(descendant::VP[@verdict='inconclusive']) = 0)       ])}"  />
				</xsl:when>
				<xsl:when test="count(descendant::ANSWER) > 0 and count(descendant::VP) = 0 ">
					<STATUS name="error"  label="{document($languagePack)//entry[@key='STATUS_ERROR']}"  value="{count(.[count(descendant::ANSWER[@verdict='error']) >= 1])}" />
					<STATUS name="failed"  label="{document($languagePack)//entry[@key='STATUS_FAIL']}"  value="{count(.[(count(descendant::ANSWER[@verdict='fail']) >= 1) and  (count(descendant::ANSWER[@verdict='error']) = 0)           ])}" />
					<STATUS name="inconclusive"  label="{document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']}"  value="{count(.[(count(descendant::ANSWER[@verdict='inconclusive']) >= 1) and  (count(descendant::ANSWER[@verdict='error']) = 0)    and  (count(descendant::ANSWER[@verdict='fail']) = 0)           ])}" />
					<STATUS name="passed"  label="{document($languagePack)//entry[@key='STATUS_PASS']}"  value="{count(.[(count(descendant::ANSWER[@verdict='pass']) >= 1) and  (count(descendant::ANSWER[@verdict='error']) = 0)    and  (count(descendant::ANSWER[@verdict='fail']) = 0)    and  (count(descendant::ANSWER[@verdict='inconclusive']) = 0)       ])}"  />
				</xsl:when>
				<xsl:when test="count(descendant::CALL) > 0 and count(descendant::ANSWER) = 0 and count(descendant::VP) = 0 ">
					<STATUS name="error"  label="{document($languagePack)//entry[@key='STATUS_ERROR']}"  value="{count(.[count(descendant::CALL[@verdict='error']) >= 1])}" />
					<STATUS name="failed"  label="{document($languagePack)//entry[@key='STATUS_FAIL']}"  			   value="{count(.[(count(descendant::CALL[@verdict='fail']) >= 1) and  (count(descendant::CALL[@verdict='error']) = 0)           ])}" />
					<STATUS name="inconclusive"  label="{document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']}"  value="{count(.[(count(descendant::CALL[@verdict='inconclusive']) >= 1) and  (count(descendant::CALL[@verdict='error']) = 0)    and  (count(descendant::CALL[@verdict='fail']) = 0)           ])}" />
					<STATUS name="passed"  label="{document($languagePack)//entry[@key='STATUS_PASS']}"  value="{count(.[(count(descendant::CALL[@verdict='pass']) >= 1) and  (count(descendant::CALL[@verdict='error']) = 0)    and  (count(descendant::CALL[@verdict='fail']) = 0)    and  (count(descendant::CALL[@verdict='inconclusive']) = 0)       ])}"  />
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</TEST_RESULTS>	
</xsl:template>

<!-- set CALL Graph Data -->
<xsl:template name="setCallsGraphData">
	<CALL_RESULTS>
		<STATUS name="passed"  label="{document($languagePack)//entry[@key='STATUS_PASS']}"  value="{count(descendant::CALL[@verdict='pass'])}" />
		<STATUS name="failed"  label="{document($languagePack)//entry[@key='STATUS_FAIL']}"  value="{count(descendant::CALL[@verdict='fail'])}" />
		<STATUS name="inconclusive"  label="{document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']}"  value="{count(descendant::CALL[@verdict='inconclusive'])}" />
		<STATUS name="error"  label="{document($languagePack)//entry[@key='STATUS_ERROR']}"  value="{count(descendant::CALL[@verdict='error'])}"  />
	</CALL_RESULTS>
</xsl:template>


<!-- set ANSWER Graph Data -->
<xsl:template name="setAnswersGraphData">
	<ANSWER_RESULTS>
		<STATUS name="passed"  label="{document($languagePack)//entry[@key='STATUS_PASS']}"  value="{count(descendant::ANSWER[@verdict='pass'])}" />
		<STATUS name="failed"  label="{document($languagePack)//entry[@key='STATUS_FAIL']}"  value="{count(descendant::ANSWER[@verdict='fail'])}" />
		<STATUS name="inconclusive"  label="{document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']}"  value="{count(descendant::ANSWER[@verdict='inconclusive'])}" />
		<STATUS name="error"  label="{document($languagePack)//entry[@key='STATUS_ERROR']}"  value="{count(descendant::ANSWER[@verdict='error'])}"  />
	</ANSWER_RESULTS>
</xsl:template>

<!-- set VP  Graph Data -->
<xsl:template name="setVPsGraphData">
	<VP_RESULTS>
		<STATUS name="passed"  label="{document($languagePack)//entry[@key='STATUS_PASS']}"  value="{count(descendant::VP[@verdict='pass'])}" />
		<STATUS name="failed"  label="{document($languagePack)//entry[@key='STATUS_FAIL']}"  value="{count(descendant::VP[@verdict='fail'])}" />
		<STATUS name="inconclusive"  label="{document($languagePack)//entry[@key='STATUS_INCONCLUSIVE']}"  value="{count(descendant::VP[@verdict='inconclusive'])}" />
		<STATUS name="error"  label="{document($languagePack)//entry[@key='STATUS_ERROR']}"  value="{count(descendant::VP[@verdict='error'])}"  />
	</VP_RESULTS>
</xsl:template>

<!--- ################### Generate the test log part ###################### -->

<xsl:template name="createEvent">

	<!-- Ignore TEST, EXPECTED and RECEIVED nodes ... -->
	<xsl:if test="(name() != 'EXPECTED') and (name() != 'RECEIVED') and (name() != 'TEST') ">
		
		
		<xsl:choose>
			<xsl:when test="@path != ' ' and @path !=''">
				
					<EVENT 
				linkid="{generate-id()}" 
				category="{name()}" 
				type="{@type}" 
				description="{@description}"  
				name="{@name}" 
				expected="{./EXPECTED/@value}" 
				received="{./RECEIVED/@value}"
				hostname="{@hostname}"
				datestamp="{@datestamp}"
				connectionTime="{@connectionTime}"
				path="{concat(../@path,'',substring(@path,2))}"
				sent="{@sent}"
				query="{@query}"
				timeout="{@timeout}"	
				verdict="{../@verdict}"	
				value="{@value}">
				<xsl:choose>
					<xsl:when test="(name() = 'VP') or (name() = 'CALL') or (name() = 'ANSWER')"><xsl:call-template name="setNodeVerdictFromTPTP" /></xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="setNodeVerdict" />
					</xsl:otherwise>
				</xsl:choose>
				
		</EVENT>
					
				
				
			</xsl:when>
			<xsl:otherwise>
				<EVENT 
				linkid="{generate-id()}" 
				category="{name()}" 
				type="{@type}" 
				description="{@description}"  
				name="{@name}" 
				expected="{./EXPECTED/@value}" 
				received="{./RECEIVED/@value}"
				hostname="{@hostname}"
				datestamp="{@datestamp}"
				connectionTime="{@connectionTime}"
				path="{../@path}"
				sent="{@sent}"
				query="{@query}"
				timeout="{@timeout}"	
				verdict="{../@verdict}"	
				value="{@value}">
				<xsl:choose>
					<xsl:when test="(name() = 'VP') or (name() = 'CALL') or (name() = 'ANSWER')"><xsl:call-template name="setNodeVerdictFromTPTP" /></xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="setNodeVerdict" />
					</xsl:otherwise>
				</xsl:choose>
				
		</EVENT>

			</xsl:otherwise>
		</xsl:choose>
		
		
	</xsl:if>
</xsl:template>







<xsl:template match="/">


<FUNCTIONAL_DATA>


	
	   
	<SOA_FUNCTIONAL_DATA>
		<xsl:apply-templates select="FUNCTIONAL_DATA" />
	
		<!-- For each Run -->
		<xsl:for-each select="/FUNCTIONAL_DATA/RUN">
		<RUN>
			<xsl:apply-templates select="." />
			
						
			
			<!-- For each schedule inside a run -->
			<xsl:for-each select="./SCHEDULE">
			<SCHEDULE>
				<xsl:apply-templates select="." />
				
								
				<!-- For each group inside a schedule -->
				<xsl:for-each select="./GROUP">
				<GROUP>
					<xsl:apply-templates select="." />
					
					
					
					<!-- For each user inside a group -->
					<xsl:for-each select="./USER">
					<USER>
						<xsl:apply-templates select="." />
						
						<!-- For each custom_msg inside a user -->
						<xsl:for-each select="./CUSTOM_MSG">
							<CUSTOM_MSG>
								<xsl:apply-templates select="." />
							</CUSTOM_MSG>
						</xsl:for-each>
						
						<!-- For each test inside a user -->
						<xsl:for-each select="./TEST">
						<TEST>
							<xsl:apply-templates select="." />
							
							<!-- For each defect inside a test -->
							<xsl:for-each select="./DEFECT">
								<DEFECT>
									<xsl:apply-templates select="." />
								</DEFECT>
							</xsl:for-each>
							
							
							<!-- For each custom_msg inside a test -->
							<xsl:for-each select="./CUSTOM_MSG">
								<CUSTOM_MSG>
									<xsl:apply-templates select="." />
								</CUSTOM_MSG>
							</xsl:for-each>
							
							<!-- For each call inside a test -->
							<xsl:for-each select="./CALL">
							<CALL>
								<xsl:apply-templates select="." />
								
								<!-- For each defect inside a call -->
								<xsl:for-each select="./DEFECT">
									<DEFECT>
										<xsl:apply-templates select="." />
									</DEFECT>
								</xsl:for-each>
									
								<!-- For each custom_msg inside a call -->
								<xsl:for-each select="./CUSTOM_MSG">
									<CUSTOM_MSG>
										<xsl:apply-templates select="." />
									</CUSTOM_MSG>
								</xsl:for-each>
								
								<!-- For each answer inside a test -->
								<xsl:for-each select="./ANSWER">
									<ANSWER>
										<xsl:apply-templates select="." />
										
										<!-- For each defect inside an answer -->
										<xsl:for-each select="./DEFECT">
											<DEFECT>
												<xsl:apply-templates select="." />
											</DEFECT>
										</xsl:for-each>
										
										
										<!-- For each custom_msg inside an answer -->
										<xsl:for-each select="./CUSTOM_MSG">
											<CUSTOM_MSG>
												<xsl:apply-templates select="." />
											</CUSTOM_MSG>
										</xsl:for-each>
										
										
										<!-- For each vp inside a test -->
										<xsl:for-each select="./VP">
											<VP>
												<xsl:apply-templates select="." />
												
												<!-- For each defect inside a VP -->
												<xsl:for-each select="./DEFECT">
													<DEFECT>
														<xsl:apply-templates select="." />
													</DEFECT>
												</xsl:for-each>
												
												
												<!-- For each custom_msg inside a vp -->
												<xsl:for-each select="./CUSTOM_MSG">
													<CUSTOM_MSG>
														<xsl:apply-templates select="." />
													</CUSTOM_MSG>
												</xsl:for-each>
												
												
												<!-- For each expected inside a test -->
												<xsl:for-each select="./EXPECTED">
													<EXPECTED>
														<xsl:apply-templates select="." />
													</EXPECTED>
												</xsl:for-each>
												<!-- For each received inside a test -->
												<xsl:for-each select="./RECEIVED">
													<RECEIVED>
														<xsl:apply-templates select="." />
													</RECEIVED>
												</xsl:for-each>
											</VP>
										</xsl:for-each>
									</ANSWER>
								</xsl:for-each>
							</CALL>
							</xsl:for-each>
						</TEST>
						</xsl:for-each>
					</USER>
					</xsl:for-each>
				</GROUP>
				</xsl:for-each>
			</SCHEDULE>
			</xsl:for-each>
		</RUN>
		</xsl:for-each>
	</SOA_FUNCTIONAL_DATA>

	<SOA_SCALABLE_FUNCTIONAL_DATA>
		<xsl:for-each select="/FUNCTIONAL_DATA/RUN/SCHEDULE/GROUP/descendant::*">
			<xsl:call-template name="createEvent" />	
		</xsl:for-each>
	</SOA_SCALABLE_FUNCTIONAL_DATA>



</FUNCTIONAL_DATA>
	
</xsl:template>





</xsl:stylesheet>
